@@ -26,12 +26,18 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 #ifndef LIBUNWIND_H
 #define LIBUNWIND_H
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 #include <inttypes.h>
 #include <ucontext.h>
 
 #define UNW_TARGET	x86
 #define UNW_TARGET_X86	1
 
+#define _U_TDEP_QP_TRUE	0	/* see libunwind-dynamic.h  */
+
 /* This needs to be big enough to accommodate "struct cursor", while
    leaving some slack for future expansion.  Changing this value will
    require recompiling all users of this library.  Stack allocation is
@@ -89,4 +95,8 @@ typedef ucontext_t unw_tdep_context_t;
 
 #include "libunwind-common.h"
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* LIBUNWIND_H */
