@@ -36,15 +36,23 @@ _UPT_access_mem (unw_addr_space_t as, unw_word_t addr, unw_word_t *val,
   if (write)
     {
       debug (100, "%s: mem[%lx] <- %lx\n", __FUNCTION__, addr, *val);
+#ifdef HAVE_TTRACE
+#	warning No support for ttrace() yet.
+#else
       ptrace (PTRACE_POKEDATA, pid, addr, *val);
       if (errno)
 	return -UNW_EINVAL;
+#endif
     }
   else
     {
+#ifdef HAVE_TTRACE
+#	warning No support for ttrace() yet.
+#else
       *val = ptrace (PTRACE_PEEKDATA, pid, addr, 0);
       if (errno)
 	return -UNW_EINVAL;
+#endif
       debug (100, "%s: mem[%lx] -> %lx\n", __FUNCTION__, addr, *val);
     }
   return 0;
