@@ -51,7 +51,7 @@ find_gp (struct UPT_info *ui, Elf64_Phdr *pdyn, Elf64_Addr load_base)
     {
       /* If we have a PT_DYNAMIC program header, fetch the gp-value
 	 from the DT_PLTGOT entry.  */
-      Elf64_Dyn *dyn = (Elf64_Dyn *) (pdyn->p_offset + ui->ei.image);
+      Elf64_Dyn *dyn = (Elf64_Dyn *) (pdyn->p_offset + (char *) ui->ei.image);
       for (; dyn->d_tag != DT_NULL; ++dyn)
 	if (dyn->d_tag == DT_PLTGOT)
 	  {
@@ -84,7 +84,7 @@ find_gp (struct UPT_info *ui, Elf64_Phdr *pdyn, Elf64_Addr load_base)
       if (strcmp (strtab + shdr->sh_name, ".opd") == 0
 	  && shdr->sh_size >= 16)
 	{
-	  gp = ((Elf64_Addr *) (ui->ei.image + shdr->sh_offset))[1];
+	  gp = ((Elf64_Addr *) ((char *) ui->ei.image + shdr->sh_offset))[1];
 	  goto done;
 	}
       shdr = (Elf64_Shdr *) (((char *) shdr) + ehdr->e_shentsize);
@@ -149,7 +149,16 @@ _UPTi_find_unwind_table (struct UPT_info *ui, unw_addr_space_t as,
   return &ui->di_cache;
 }
 
-#endif /* UNW_TARGET_IA64 */
+#elif UNW_TARGET_X86
+
+HIDDEN unw_dyn_info_t *
+_UPTi_find_unwind_table (struct UPT_info *ui, unw_addr_space_t as,
+			 char *path, unw_word_t segbase, unw_word_t mapoff)
+{
+  return NULL;
+}
+
+#endif /* UNW_TARGET_X86 */
 
 static unw_dyn_info_t *
 get_unwind_info (struct UPT_info *ui, unw_addr_space_t as, unw_word_t ip)
@@ -158,7 +167,7 @@ get_unwind_info (struct UPT_info *ui, unw_addr_space_t as, unw_word_t ip)
   char path[PATH_MAX];
   unw_dyn_info_t *di;
 
-#if UNW_TARGET_IA64
+#if UNW_TARGET_IA64 && defined(__linux)
   if (!ui->ktab.start_ip && _Uia64_get_kernel_table (&ui->ktab) < 0)
     return NULL;
 
@@ -205,5 +214,29 @@ _UPT_find_proc_info (unw_addr_space_t as, unw_word_t ip, unw_proc_info_t *pi,
   if (!di)
     return -UNW_ENOINFO;
 
-  return _Uia64_search_unwind_table (as, ip, di, pi, need_unwind_info, arg);
+#if UNW_TARGET_IA64
+  if (di == &ui->ktab)
+    {
+      /* The kernel unwind table resides in local memory, so we have
+	 to use the local address space to search it.  Since
+	 _UPT_put_unwind_info() has no easy way of detecting this
+	 case, we simply make a copy of the unwind-info, so
+	 _UPT_put_unwind_info() can always free() the unwind-info
+	 without ill effects.  */
+      int ret = tdep_search_unwind_table (unw_local_addr_space, ip, di, pi,
+					  need_unwind_info, arg);
+      if (ret >= 0 && need_unwind_info)
+	{
+	  void *mem = malloc (pi->unwind_info_size);
+
+	  if (!mem)
+	    return -UNW_ENOMEM;
+	  memcpy (mem, pi->unwind_info, pi->unwind_info_size);
+	  pi->unwind_info = mem;
+	}
+      return ret;
+    }
+  else
+#endif
+  return tdep_search_unwind_table (as, ip, di, pi, need_unwind_info, arg);
 }
