@@ -31,9 +31,10 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 
 #ifndef UNW_REMOTE_ONLY
 
-HIDDEN inline int
-ia64_local_resume (unw_addr_space_t as, unw_cursor_t *cursor, void *arg)
+static inline int
+local_resume (unw_addr_space_t as, unw_cursor_t *cursor, void *arg)
 {
+#ifndef __hpux
   unw_word_t val, sol, sof, pri_unat, n, pfs;
   struct cursor *c = (struct cursor *) cursor;
   struct
@@ -137,6 +138,15 @@ ia64_local_resume (unw_addr_space_t as, unw_cursor_t *cursor, void *arg)
       extra.r18 = c->eh_args[3];
     }
   _Uia64_install_context (c, pri_unat, (unw_word_t *) &extra);
+#else
+  return -UNW_EINVAL;
+#endif
+}
+
+HIDDEN int
+ia64_local_resume (unw_addr_space_t as, unw_cursor_t *cursor, void *arg)
+{
+  return local_resume (as, cursor, arg);
 }
 
 #endif /* !UNW_REMOTE_ONLY */
@@ -146,6 +156,7 @@ ia64_local_resume (unw_addr_space_t as, unw_cursor_t *cursor, void *arg)
 static inline int
 remote_install_cursor (struct cursor *c)
 {
+#ifndef __hpux
   int (*access_reg) (unw_addr_space_t, unw_regnum_t, unw_word_t *,
 		     int write, void *);
   int (*access_fpreg) (unw_addr_space_t, unw_regnum_t, unw_fpreg_t *,
@@ -221,6 +232,7 @@ remote_install_cursor (struct cursor *c)
 	}
     }
   return (*c->as->acc.resume) (c->as, (unw_cursor_t *) c, c->as_arg);
+#endif
 }
 
 #endif
@@ -231,7 +243,7 @@ unw_resume (unw_cursor_t *cursor)
   struct cursor *c = (struct cursor *) cursor;
 
 #ifdef UNW_LOCAL_ONLY
-  return ia64_local_resume (c->as, cursor, c->as_arg);
+  return local_resume (c->as, cursor, c->as_arg);
 #else
   {
     int ret;
