@@ -36,7 +36,7 @@ unw_set_caching_policy (unw_addr_space_t as, unw_caching_policy_t policy)
 
 #ifndef HAVE___THREAD
   if (policy == UNW_CACHE_PER_THREAD)
-    return -UNW_EINVAL;
+    policy = UNW_CACHE_GLOBAL;
 #endif
   as->caching_policy = policy;
 
