@@ -1,2 +1,4 @@
+#ifndef UNW_REMOTE_ONLY
 #define UNW_LOCAL_ONLY
 #include "Gia64-test-stack.c"
+#endif
