@@ -1,2 +1,4 @@
+#ifndef UNW_REMOTE_ONLY
 #define UNW_LOCAL_ONLY
 #include "Gtest-resume-sig.c"
+#endif
